========
User API
========

Base models
===========

.. autoclass:: ravenpy.models.base.Raven
   :members:
   :noindex:

.. autoclass:: ravenpy.models.base.Ostrich
   :members:
   :noindex:

.. autoclass:: ravenpy.models.multimodel.RavenMultiModel
   :members:
   :noindex:

Emulators
=========

.. automodule::  ravenpy.models.emulators
   :members:
   :noindex:


Configuration options
=====================

.. automodule::  ravenpy.models.rv
   :members:
   :noindex:

.. automodule::  ravenpy.models.commands
   :members:
   :noindex:


Importers
=========

.. automodule::  ravenpy.models.importers
   :members:
   :noindex:


Utilities
=========

Geospatial
----------
.. automodule::  ravenpy.utilities.io
   :members:
   :noindex:

.. automodule::  ravenpy.utilities.geo
   :members:
   :noindex:

.. automodule::  ravenpy.utilities.geoserver
   :members:
   :noindex:

Graphics
--------
.. automodule::  ravenpy.utilities.graphs
   :members:
   :noindex:

Regionalization
---------------

.. automodule::  ravenpy.utilities.regionalization
   :members:
   :noindex:
